==> aptechka-0.41.6.tgz: package/lib/attribute/index.js <==
var g = (t) => {
  throw TypeError(t);
};
var m = (t, e, s) => e.has(t) || g("Cannot " + s);
var r = (t, e, s) => (m(t, e, "read from private field"), s ? s.call(t) : e.get(t)), h = (t, e, s) => e.has(t) ? g("Cannot add the same private member more than once") : e instanceof WeakSet ? e.add(t) : e.set(t, s), c = (t, e, s, o) => (m(t, e, "write to private field"), o ? o.call(t, s) : e.set(t, s), s), v = (t, e, s) => (m(t, e, "access private method"), s);
import { S as y } from "../Store-Cm3LPXlx.js";
import { p as S } from "../attributes-69we3byR.js";
import { i as w } from "../browser-0zX67oeU.js";
import { g as x } from "../dom-0S_WDL4g.js";
var i, u, a, b, n, p;
class N extends y {
  constructor(s, o, A, f) {
    super(A, f);
    h(this, n);
    h(this, i, null);
    h(this, u);
    h(this, a, null);
    h(this, b, !1);
    c(this, u, o), w && (c(this, i, x(s)), c(this, a, new MutationObserver((l) => {
      l.forEach((d) => {
        d.type === "attributes" && d.attributeName === r(this, u) && v(this, n, p).call(this);
      });
    })), f != null && f.sync && this.subscribe((l) => {
      r(this, i).setAttribute(r(this, u), l.current.toString());
    }));
  }
  subscribe(s) {
    return this.subscribers.size || this.observe(), super.subscribe(s);
  }
  unsubscribe(s) {
    super.unsubscribe(s), this.subscribers.size || this.unobserve();
  }
  observe() {
    r(this, b) || (c(this, b, !0), r(this, a).observe(r(this, i), {
      attributes: !0
    }), v(this, n, p).call(this));
  }
  unobserve() {
    r(this, b) && (c(this, b, !1), r(this, a).disconnect());
  }
  close() {
    super.close(), this.unobserve();
  }
}
i = new WeakMap(), u = new WeakMap(), a = new WeakMap(), b = new WeakMap(), n = new WeakSet(), p = function() {
  const s = r(this, i).getAttribute(r(this, u));
  s != null && (this.current = S(s));
};
export {
  N as Attribute
};

==> aptechka-0.42.1.tgz: package/lib/attribute/index.js <==
var g = (t) => {
  throw TypeError(t);
};
var m = (t, e, s) => e.has(t) || g("Cannot " + s);
var r = (t, e, s) => (m(t, e, "read from private field"), s ? s.call(t) : e.get(t)), h = (t, e, s) => e.has(t) ? g("Cannot add the same private member more than once") : e instanceof WeakSet ? e.add(t) : e.set(t, s), c = (t, e, s, o) => (m(t, e, "write to private field"), o ? o.call(t, s) : e.set(t, s), s), v = (t, e, s) => (m(t, e, "access private method"), s);
import { S as y } from "../Store-Cm3LPXlx.js";
import { p as S } from "../attributes-69we3byR.js";
import { i as w } from "../browser-0zX67oeU.js";
import { g as x } from "../dom-CVWzyXPH.js";
var i, u, a, b, n, p;
class N extends y {
  constructor(s, o, A, f) {
    super(A, f);
    h(this, n);
    h(this, i, null);
    h(this, u);
    h(this, a, null);
    h(this, b, !1);
    c(this, u, o), w && (c(this, i, x(s)), c(this, a, new MutationObserver((l) => {
      l.forEach((d) => {
        d.type === "attributes" && d.attributeName === r(this, u) && v(this, n, p).call(this);
      });
    })), f != null && f.sync && this.subscribe((l) => {
      r(this, i).setAttribute(r(this, u), l.current.toString());
    }));
  }
  subscribe(s) {
    return this.subscribers.size || this.observe(), super.subscribe(s);
  }
  unsubscribe(s) {
    super.unsubscribe(s), this.subscribers.size || this.unobserve();
  }
  observe() {
    r(this, b) || (c(this, b, !0), r(this, a).observe(r(this, i), {
      attributes: !0
    }), v(this, n, p).call(this));
  }
  unobserve() {
    r(this, b) && (c(this, b, !1), r(this, a).disconnect());
  }
  close() {
    super.close(), this.unobserve();
  }
}
i = new WeakMap(), u = new WeakMap(), a = new WeakMap(), b = new WeakMap(), n = new WeakSet(), p = function() {
  const s = r(this, i).getAttribute(r(this, u));
  s != null && (this.current = S(s));
};
export {
  N as Attribute
};
